@@ -171,6 +171,16 @@ public class A3Screen implements A3CanvasInterface {
         canvas.setDefaultCameraRot(rot);
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z) {
+        canvas.setDefaultCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev) {
+        canvas.setDefaultCameraRev(rev);
+    }
+
     @Override
     public void setDefaultCameraScale(double s) {
         canvas.setDefaultCameraScale(s);
@@ -331,6 +341,56 @@ public class A3Screen implements A3CanvasInterface {
         return canvas.getCameraTargetRot();
     }
 
+    @Override
+    public void setCameraRev(double x, double y, double z) {
+        canvas.setCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev) {
+        canvas.setCameraRev(rev);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x, double y, double z) {
+        canvas.setCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev) {
+        canvas.setCameraRevImmediately(rev);
+    }
+
+    @Override
+    public void mulCameraRev(double x, double y, double z) {
+        canvas.mulCameraRev(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev) {
+        canvas.mulCameraRev(rev);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x, double y, double z) {
+        canvas.mulCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev) {
+        canvas.setCameraRevImmediately(rev);
+    }
+
+    @Override
+    public Vector3d getCameraRev() {
+        return canvas.getCameraRev();
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev() {
+        return canvas.getCameraTargetRev();
+    }
+
     @Override
     public void setCameraScale(double s) {
         canvas.setCameraScale(s);
@@ -600,6 +660,16 @@ public class A3Screen implements A3CanvasInterface {
         canvas.setDefaultCameraRot(rot,scene);
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z,int scene) {
+        canvas.setDefaultCameraRev(x,y,z,scene);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev,int scene) {
+        canvas.setDefaultCameraRev(rev,scene);
+    }
+
     @Override
     public void setDefaultCameraScale(double s,int scene) {
         canvas.setDefaultCameraScale(s,scene);
@@ -760,6 +830,56 @@ public class A3Screen implements A3CanvasInterface {
         return canvas.getCameraTargetRot(scene);
     }
 
+    @Override
+    public void setCameraRev(double x,double y,double z,int scene) {
+        canvas.setCameraRev(x,y,z,scene);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev,int scene) {
+        canvas.setCameraRev(rev,scene);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x,double y,double z,int scene) {
+        canvas.setCameraRevImmediately(x,y,z,scene);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev,int scene) {
+        canvas.setCameraRevImmediately(rev,scene);
+    }
+
+    @Override
+    public void mulCameraRev(double x,double y,double z,int scene) {
+        canvas.mulCameraRev(x,y,z,scene);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev,int scene) {
+        canvas.mulCameraRev(rev,scene);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x,double y,double z,int scene) {
+        canvas.mulCameraRevImmediately(x,y,z,scene);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev,int scene) {
+        canvas.mulCameraRevImmediately(rev,scene);
+    }
+
+    @Override
+    public Vector3d getCameraRev(int scene) {
+        return canvas.getCameraRev(scene);
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev(int scene) {
+        return canvas.getCameraTargetRev(scene);
+    }
+
     @Override
     public void setCameraScale(double s,int scene) {
         canvas.setCameraScale(s,scene);
@@ -831,8 +951,8 @@ public class A3Screen implements A3CanvasInterface {
     }
 
     @Override
-    public void setNavigationMode(NaviMode m,int scene,Object...params) {
-        canvas.setNavigationMode(m,scene,params);
+    public void setNavigationMode(int scene,NaviMode m,Object...params) {
+        canvas.setNavigationMode(scene,m,params);
     }
 
     @Override
