@@ -172,6 +172,7 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
                 ;
             }
         }
+        /*
         if (mixer==null) {
             try {
                 mixer = new jp.sourceforge.acerola3d.sound.JOALMixer2(environment);
@@ -186,7 +187,6 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
                 ;
             }
         }
-        /*
         if (mixer==null) {
             try {
                 //mixer = new com.sun.j3d.audioengines.headspace.HeadspaceMixer(environment);
@@ -319,6 +319,16 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         scene.setDefaultCameraRot(rot);
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z) {
+        scene.setDefaultCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev) {
+        scene.setDefaultCameraRev(rev);
+    }
+
     @Override
     public void setDefaultCameraScale(double s) {
         scene.setDefaultCameraScale(s);
@@ -479,6 +489,60 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         return scene.getCameraTargetRot();
     }
 
+    @Override
+    public void setCameraRev(double x,double y,double z) {
+        scene.setCameraRot(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev) {
+        scene.setCameraRot(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x,double y,double z) {
+        scene.setCameraRotImmediately(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev) {
+        scene.setCameraRotImmediately(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z);
+    }
+
+    @Override
+    public void mulCameraRev(double x,double y,double z) {
+        scene.mulCameraRot(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev) {
+        scene.mulCameraRot(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x,double y,double z) {
+        scene.mulCameraRotImmediately(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev) {
+        scene.mulCameraRotImmediately(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z);
+    }
+
+    @Override
+    public Vector3d getCameraRev() {
+        Vector3d ret = scene.getCameraRot();
+        ret.scale(180.0/Math.PI);
+        return ret;
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev() {
+        Vector3d ret = scene.getCameraTargetRot();
+        ret.scale(180.0/Math.PI);
+        return ret;
+    }
+
     @Override
     public void setCameraScale(double s) {
         scene.setCameraScale(s);
@@ -738,6 +802,16 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
             throw new IllegalArgumentException();
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z,int scene) {
+        setDefaultCameraRot(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z,scene);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev,int scene) {
+        setDefaultCameraRot(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z,scene);
+    }
+
     @Override
     public void setDefaultCameraScale(double s,int scene) {
         Scene sTmp = scenes.get(scene);
@@ -1026,6 +1100,60 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
             throw new IllegalArgumentException();
     }
 
+    @Override
+    public void setCameraRev(double x,double y,double z,int scene) {
+        setCameraRot(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z,scene);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev,int scene) {
+        setCameraRot(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x,double y,double z,int scene) {
+        setCameraRotImmediately(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z,scene);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev,int scene) {
+        setCameraRotImmediately(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z,scene);
+    }
+
+    @Override
+    public void mulCameraRev(double x,double y,double z,int scene) {
+        mulCameraRot(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z,scene);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev,int scene) {
+        mulCameraRot(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z,scene);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x,double y,double z,int scene) {
+        mulCameraRotImmediately(Math.PI/180.0*x,Math.PI/180.0*y,Math.PI/180.0*z,scene);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev,int scene) {
+        mulCameraRotImmediately(Math.PI/180.0*rev.x,Math.PI/180.0*rev.y,Math.PI/180.0*rev.z,scene);
+    }
+
+    @Override
+    public Vector3d getCameraRev(int scene) {
+        Vector3d ret = getCameraRot(scene);
+        ret.scale(180.0/Math.PI);
+        return ret;
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev(int scene) {
+        Vector3d ret = getCameraTargetRot(scene);
+        ret.scale(180.0/Math.PI);
+        return ret;
+    }
+
     @Override
     public void setCameraScale(double s,int scene) {
         Scene sTmp = scenes.get(scene);
@@ -1153,7 +1281,7 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
     }
 
     @Override
-    public void setNavigationMode(NaviMode m,int scene,Object...params) {
+    public void setNavigationMode(int scene,NaviMode m,Object...params) {
         Scene s = scenes.get(scene);
         if (s!=null)
             s.setNavigationMode(m,params);
