@@ -162,6 +162,16 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
         universe.setDefaultCameraRot(rot);
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z) {
+        universe.setDefaultCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev) {
+        universe.setDefaultCameraRev(rev);
+    }
+
     @Override
     public void setDefaultCameraScale(double s) {
         universe.setDefaultCameraScale(s);
@@ -322,6 +332,56 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
         return universe.getCameraTargetRot();
     }
 
+    @Override
+    public void setCameraRev(double x,double y,double z) {
+        universe.setCameraRev(x,y,z);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev) {
+        universe.setCameraRev(rev);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x,double y,double z) {
+        universe.setCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev) {
+        universe.setCameraRevImmediately(rev);
+    }
+
+    @Override
+    public void mulCameraRev(double x,double y,double z) {
+        universe.mulCameraRev(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev) {
+        universe.mulCameraRev(rev);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x,double y,double z) {
+        universe.mulCameraRevImmediately(x,y,z);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev) {
+        universe.mulCameraRevImmediately(rev);
+    }
+
+    @Override
+    public Vector3d getCameraRev() {
+        return universe.getCameraRev();
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev() {
+        return universe.getCameraTargetRev();
+    }
+
     @Override
     public void setCameraScale(double s) {
         universe.setCameraScale(s);
@@ -706,6 +766,16 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
         universe.setDefaultCameraRot(rot,scene);
     }
 
+    @Override
+    public void setDefaultCameraRev(double x,double y,double z,int scene) {
+        universe.setDefaultCameraRev(x,y,z,scene);
+    }
+
+    @Override
+    public void setDefaultCameraRev(Vector3d rev,int scene) {
+        universe.setDefaultCameraRev(rev,scene);
+    }
+
     @Override
     public void setDefaultCameraScale(double s,int scene) {
         universe.setDefaultCameraScale(s,scene);
@@ -866,6 +936,56 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
         return universe.getCameraTargetRot();
     }
 
+    @Override
+    public void setCameraRev(double x,double y,double z,int scene) {
+        universe.setCameraRev(x,y,z,scene);
+    }
+
+    @Override
+    public void setCameraRev(Vector3d rev,int scene) {
+        universe.setCameraRev(rev,scene);
+    }
+
+    @Override
+    public void setCameraRevImmediately(double x,double y,double z,int scene) {
+        universe.setCameraRevImmediately(x,y,z,scene);
+    }
+
+    @Override
+    public void setCameraRevImmediately(Vector3d rev,int scene) {
+        universe.setCameraRevImmediately(rev,scene);
+    }
+
+    @Override
+    public void mulCameraRev(double x,double y,double z,int scene) {
+        universe.mulCameraRev(x,y,z,scene);
+    }
+
+    @Override
+    public void mulCameraRev(Vector3d rev,int scene) {
+        universe.mulCameraRev(rev,scene);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(double x,double y,double z,int scene) {
+        universe.mulCameraRevImmediately(x,y,z,scene);
+    }
+
+    @Override
+    public void mulCameraRevImmediately(Vector3d rev,int scene) {
+        universe.setCameraRevImmediately(rev,scene);
+    }
+
+    @Override
+    public Vector3d getCameraRev(int scene) {
+        return universe.getCameraRev();
+    }
+
+    @Override
+    public Vector3d getCameraTargetRev(int scene) {
+        return universe.getCameraTargetRev();
+    }
+
     @Override
     public void setCameraScale(double s,int scene) {
         universe.setCameraScale(s,scene);
@@ -937,8 +1057,8 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
     }
 
     @Override
-    public void setNavigationMode(NaviMode m,int scene,Object...params) {
-        universe.setNavigationMode(m,scene,params);
+    public void setNavigationMode(int scene,NaviMode m,Object...params) {
+        universe.setNavigationMode(scene,m,params);
     }
 
     @Override
