@@ -735,6 +735,16 @@ class TransCanvas3D extends JPanel implements AncestorListener {
         this.resizeValidationDelay = resizeValidationDelay;
     }
 
+    //kenji
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        canvas.insertTaskIntoRenderingLoop(task);
+    }
+
+    //kenji
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        canvas.removeTaskFromRenderingLoop(task);
+    }
+
     /**
      * This class is the internal Canvas3D that is used and sent to
      * Java 3D. It is remote controlled through TransCanvas3D and is modified to be
@@ -884,6 +894,28 @@ class TransCanvas3D extends JPanel implements AncestorListener {
             } else {
                 //                System.err.println("SWAP WITHOUT RENDERER RUNNING");
             }
+
+            //kenji
+            synchronized(renderingLoopTasks) {
+                for (Runnable r:renderingLoopTasks) {
+                    r.run();
+                }
+            }
+        }
+
+        //kenji
+        ArrayList<Runnable> renderingLoopTasks = new ArrayList<Runnable>();
+        public void insertTaskIntoRenderingLoop(Runnable task) {
+            synchronized(renderingLoopTasks) {
+                renderingLoopTasks.add(task);
+            }
+        }
+
+        //kenji
+        public void removeTaskFromRenderingLoop(Runnable task) {
+            synchronized(renderingLoopTasks) {
+                renderingLoopTasks.remove(task);
+            }
         }
 
         /**
